# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetEncryptedDataResult',
    'AwaitableGetEncryptedDataResult',
    'get_encrypted_data',
    'get_encrypted_data_output',
]

@pulumi.output_type
class GetEncryptedDataResult:
    """
    A collection of values returned by getEncryptedData.
    """
    def __init__(__self__, associated_data=None, ciphertext=None, crypto_endpoint=None, id=None, key_id=None, plaintext=None):
        if associated_data and not isinstance(associated_data, dict):
            raise TypeError("Expected argument 'associated_data' to be a dict")
        pulumi.set(__self__, "associated_data", associated_data)
        if ciphertext and not isinstance(ciphertext, str):
            raise TypeError("Expected argument 'ciphertext' to be a str")
        pulumi.set(__self__, "ciphertext", ciphertext)
        if crypto_endpoint and not isinstance(crypto_endpoint, str):
            raise TypeError("Expected argument 'crypto_endpoint' to be a str")
        pulumi.set(__self__, "crypto_endpoint", crypto_endpoint)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if key_id and not isinstance(key_id, str):
            raise TypeError("Expected argument 'key_id' to be a str")
        pulumi.set(__self__, "key_id", key_id)
        if plaintext and not isinstance(plaintext, str):
            raise TypeError("Expected argument 'plaintext' to be a str")
        pulumi.set(__self__, "plaintext", plaintext)

    @property
    @pulumi.getter(name="associatedData")
    def associated_data(self) -> Optional[Mapping[str, Any]]:
        return pulumi.get(self, "associated_data")

    @property
    @pulumi.getter
    def ciphertext(self) -> str:
        """
        The encrypted data.
        """
        return pulumi.get(self, "ciphertext")

    @property
    @pulumi.getter(name="cryptoEndpoint")
    def crypto_endpoint(self) -> str:
        return pulumi.get(self, "crypto_endpoint")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="keyId")
    def key_id(self) -> str:
        return pulumi.get(self, "key_id")

    @property
    @pulumi.getter
    def plaintext(self) -> str:
        return pulumi.get(self, "plaintext")


class AwaitableGetEncryptedDataResult(GetEncryptedDataResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetEncryptedDataResult(
            associated_data=self.associated_data,
            ciphertext=self.ciphertext,
            crypto_endpoint=self.crypto_endpoint,
            id=self.id,
            key_id=self.key_id,
            plaintext=self.plaintext)


def get_encrypted_data(associated_data: Optional[Mapping[str, Any]] = None,
                       crypto_endpoint: Optional[str] = None,
                       key_id: Optional[str] = None,
                       plaintext: Optional[str] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetEncryptedDataResult:
    """
    The `Kms.EncryptedData` data source provides details about a specific EncryptedData

    Encrypts data using the given EncryptDataDetails resource.
    Plaintext included in the example request is a base64-encoded value
    of a UTF-8 string.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_encrypted_data = oci.Kms.get_encrypted_data(crypto_endpoint=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        key_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        plaintext=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        associated_data=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param Mapping[str, Any] associated_data: Information that can be used to provide an encryption context for the encrypted data. The length of the string representation of the associatedData must be fewer than 4096 characters.
    :param str crypto_endpoint: The service endpoint to perform cryptographic operations against. Cryptographic operations include 'Encrypt,' 'Decrypt,' and 'GenerateDataEncryptionKey' operations. see Vault Crypto endpoint.
    :param str key_id: The OCID of the key to encrypt with.
    :param str plaintext: The plaintext data to encrypt.
    """
    __args__ = dict()
    __args__['associatedData'] = associated_data
    __args__['cryptoEndpoint'] = crypto_endpoint
    __args__['keyId'] = key_id
    __args__['plaintext'] = plaintext
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Kms/getEncryptedData:getEncryptedData', __args__, opts=opts, typ=GetEncryptedDataResult).value

    return AwaitableGetEncryptedDataResult(
        associated_data=__ret__.associated_data,
        ciphertext=__ret__.ciphertext,
        crypto_endpoint=__ret__.crypto_endpoint,
        id=__ret__.id,
        key_id=__ret__.key_id,
        plaintext=__ret__.plaintext)


@_utilities.lift_output_func(get_encrypted_data)
def get_encrypted_data_output(associated_data: Optional[pulumi.Input[Optional[Mapping[str, Any]]]] = None,
                              crypto_endpoint: Optional[pulumi.Input[str]] = None,
                              key_id: Optional[pulumi.Input[str]] = None,
                              plaintext: Optional[pulumi.Input[str]] = None,
                              opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetEncryptedDataResult]:
    """
    The `Kms.EncryptedData` data source provides details about a specific EncryptedData

    Encrypts data using the given EncryptDataDetails resource.
    Plaintext included in the example request is a base64-encoded value
    of a UTF-8 string.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_encrypted_data = oci.Kms.get_encrypted_data(crypto_endpoint=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        key_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        plaintext=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        associated_data=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param Mapping[str, Any] associated_data: Information that can be used to provide an encryption context for the encrypted data. The length of the string representation of the associatedData must be fewer than 4096 characters.
    :param str crypto_endpoint: The service endpoint to perform cryptographic operations against. Cryptographic operations include 'Encrypt,' 'Decrypt,' and 'GenerateDataEncryptionKey' operations. see Vault Crypto endpoint.
    :param str key_id: The OCID of the key to encrypt with.
    :param str plaintext: The plaintext data to encrypt.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from .. import _utilities
import typing
# Export this package's modules as members:
from .app_catalog_listing_resource_version_agreement import *
from .app_catalog_subscription import *
from .boot_volume import *
from .boot_volume_backup import *
from .capture_filter import *
from .cluster_network import *
from .compute_capacity_reservation import *
from .compute_cluster import *
from .compute_image_capability_schema import *
from .console_history import *
from .cpe import *
from .cross_connect import *
from .cross_connect_group import *
from .dedicated_vm_host import *
from .default_dhcp_options import *
from .default_route_table import *
from .default_security_list import *
from .dhcp_options import *
from .drg import *
from .drg_attachment import *
from .drg_attachment_management import *
from .drg_attachments_list import *
from .drg_route_distribution import *
from .drg_route_distribution_statement import *
from .drg_route_table import *
from .drg_route_table_route_rule import *
from .get_app_catalog_listing import *
from .get_app_catalog_listing_resource_version import *
from .get_app_catalog_listing_resource_versions import *
from .get_app_catalog_listings import *
from .get_app_catalog_subscriptions import *
from .get_block_volume_replica import *
from .get_block_volume_replicas import *
from .get_boot_volume import *
from .get_boot_volume_attachments import *
from .get_boot_volume_backup import *
from .get_boot_volume_backups import *
from .get_boot_volume_replica import *
from .get_boot_volume_replicas import *
from .get_boot_volumes import *
from .get_byoip_allocated_ranges import *
from .get_byoip_range import *
from .get_byoip_ranges import *
from .get_capture_filter import *
from .get_capture_filters import *
from .get_cluster_network import *
from .get_cluster_network_instances import *
from .get_cluster_networks import *
from .get_cnv_dns_resolver_association import *
from .get_compute_capacity_reservation import *
from .get_compute_capacity_reservation_instance_shapes import *
from .get_compute_capacity_reservation_instances import *
from .get_compute_capacity_reservations import *
from .get_compute_cluster import *
from .get_compute_clusters import *
from .get_compute_global_image_capability_schema import *
from .get_compute_global_image_capability_schemas import *
from .get_compute_global_image_capability_schemas_version import *
from .get_compute_global_image_capability_schemas_versions import *
from .get_compute_image_capability_schema import *
from .get_compute_image_capability_schemas import *
from .get_console_histories import *
from .get_console_history_data import *
from .get_cpe_device_shape import *
from .get_cpe_device_shapes import *
from .get_cpes import *
from .get_cross_connect import *
from .get_cross_connect_group import *
from .get_cross_connect_groups import *
from .get_cross_connect_locations import *
from .get_cross_connect_port_speed_shape import *
from .get_cross_connect_status import *
from .get_cross_connects import *
from .get_dedicated_vm_host import *
from .get_dedicated_vm_host_instance_shapes import *
from .get_dedicated_vm_host_instances import *
from .get_dedicated_vm_host_shapes import *
from .get_dedicated_vm_hosts import *
from .get_dhcp_options import *
from .get_drg_attachments import *
from .get_drg_route_distribution import *
from .get_drg_route_distribution_statements import *
from .get_drg_route_distributions import *
from .get_drg_route_rule import *
from .get_drg_route_table_route_rules import *
from .get_drg_route_tables import *
from .get_drgs import *
from .get_fast_connect_provider_service import *
from .get_fast_connect_provider_service_key import *
from .get_fast_connect_provider_services import *
from .get_image import *
from .get_image_shape import *
from .get_image_shapes import *
from .get_images import *
from .get_instance import *
from .get_instance_configuration import *
from .get_instance_configurations import *
from .get_instance_console_connections import *
from .get_instance_credentials import *
from .get_instance_devices import *
from .get_instance_maintenance_reboot import *
from .get_instance_measured_boot_report import *
from .get_instance_pool import *
from .get_instance_pool_instances import *
from .get_instance_pool_load_balancer_attachment import *
from .get_instance_pools import *
from .get_instances import *
from .get_internet_gateways import *
from .get_ipsec_algorithm import *
from .get_ipsec_config import *
from .get_ipsec_connection_tunnel import *
from .get_ipsec_connection_tunnel_error import *
from .get_ipsec_connection_tunnel_routes import *
from .get_ipsec_connection_tunnels import *
from .get_ipsec_connections import *
from .get_ipsec_status import *
from .get_ipv6 import *
from .get_ipv6s import *
from .get_letter_of_authority import *
from .get_listing_resource_version import *
from .get_listing_resource_versions import *
from .get_local_peering_gateways import *
from .get_nat_gateway import *
from .get_nat_gateways import *
from .get_network_security_group import *
from .get_network_security_group_security_rules import *
from .get_network_security_group_vnics import *
from .get_network_security_groups import *
from .get_peer_region_for_remote_peerings import *
from .get_private_ip import *
from .get_private_ips import *
from .get_public_ip import *
from .get_public_ip_pool import *
from .get_public_ip_pools import *
from .get_public_ips import *
from .get_remote_peering_connections import *
from .get_route_tables import *
from .get_security_lists import *
from .get_service_gateways import *
from .get_services import *
from .get_shape import *
from .get_shapes import *
from .get_subnet import *
from .get_subnets import *
from .get_tunnel_security_associations import *
from .get_vcn import *
from .get_vcns import *
from .get_virtual_circuit import *
from .get_virtual_circuit_bandwidth_shapes import *
from .get_virtual_circuit_public_prefixes import *
from .get_virtual_circuits import *
from .get_virtual_networks import *
from .get_vlan import *
from .get_vlans import *
from .get_vnic import *
from .get_vnic_attachments import *
from .get_volume import *
from .get_volume_attachments import *
from .get_volume_backup_policies import *
from .get_volume_backup_policy_assignments import *
from .get_volume_backups import *
from .get_volume_group_backups import *
from .get_volume_group_replica import *
from .get_volume_group_replicas import *
from .get_volume_groups import *
from .get_volumes import *
from .get_vtap import *
from .get_vtaps import *
from .image import *
from .instance import *
from .instance_configuration import *
from .instance_console_connection import *
from .instance_pool import *
from .instance_pool_instance import *
from .internet_gateway import *
from .ipsec import *
from .ipsec_connection_tunnel_management import *
from .ipv6 import *
from .listing_resource_version_agreement import *
from .local_peering_gateway import *
from .nat_gateway import *
from .network_security_group import *
from .network_security_group_security_rule import *
from .private_ip import *
from .public_ip import *
from .public_ip_pool import *
from .public_ip_pool_capacity import *
from .remote_peering_connection import *
from .route_table import *
from .route_table_attachment import *
from .security_list import *
from .service_gateway import *
from .shape_management import *
from .subnet import *
from .vcn import *
from .virtual_circuit import *
from .virtual_network import *
from .vlan import *
from .vnic_attachment import *
from .volume import *
from .volume_attachment import *
from .volume_backup import *
from .volume_backup_policy import *
from .volume_backup_policy_assignment import *
from .volume_group import *
from .volume_group_backup import *
from .vtap import *
from ._inputs import *
from . import outputs



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetTraceSnapshotDataResult',
    'AwaitableGetTraceSnapshotDataResult',
    'get_trace_snapshot_data',
    'get_trace_snapshot_data_output',
]

@pulumi.output_type
class GetTraceSnapshotDataResult:
    """
    A collection of values returned by getTraceSnapshotData.
    """
    def __init__(__self__, apm_domain_id=None, id=None, is_summarized=None, key=None, snapshot_time=None, thread_id=None, time_ended=None, time_started=None, trace_key=None, trace_snapshot_details=None):
        if apm_domain_id and not isinstance(apm_domain_id, str):
            raise TypeError("Expected argument 'apm_domain_id' to be a str")
        pulumi.set(__self__, "apm_domain_id", apm_domain_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if is_summarized and not isinstance(is_summarized, bool):
            raise TypeError("Expected argument 'is_summarized' to be a bool")
        pulumi.set(__self__, "is_summarized", is_summarized)
        if key and not isinstance(key, str):
            raise TypeError("Expected argument 'key' to be a str")
        pulumi.set(__self__, "key", key)
        if snapshot_time and not isinstance(snapshot_time, str):
            raise TypeError("Expected argument 'snapshot_time' to be a str")
        pulumi.set(__self__, "snapshot_time", snapshot_time)
        if thread_id and not isinstance(thread_id, str):
            raise TypeError("Expected argument 'thread_id' to be a str")
        pulumi.set(__self__, "thread_id", thread_id)
        if time_ended and not isinstance(time_ended, str):
            raise TypeError("Expected argument 'time_ended' to be a str")
        pulumi.set(__self__, "time_ended", time_ended)
        if time_started and not isinstance(time_started, str):
            raise TypeError("Expected argument 'time_started' to be a str")
        pulumi.set(__self__, "time_started", time_started)
        if trace_key and not isinstance(trace_key, str):
            raise TypeError("Expected argument 'trace_key' to be a str")
        pulumi.set(__self__, "trace_key", trace_key)
        if trace_snapshot_details and not isinstance(trace_snapshot_details, list):
            raise TypeError("Expected argument 'trace_snapshot_details' to be a list")
        pulumi.set(__self__, "trace_snapshot_details", trace_snapshot_details)

    @property
    @pulumi.getter(name="apmDomainId")
    def apm_domain_id(self) -> str:
        return pulumi.get(self, "apm_domain_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="isSummarized")
    def is_summarized(self) -> Optional[bool]:
        return pulumi.get(self, "is_summarized")

    @property
    @pulumi.getter
    def key(self) -> str:
        """
        Name of the property.
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter(name="snapshotTime")
    def snapshot_time(self) -> Optional[str]:
        return pulumi.get(self, "snapshot_time")

    @property
    @pulumi.getter(name="threadId")
    def thread_id(self) -> Optional[str]:
        return pulumi.get(self, "thread_id")

    @property
    @pulumi.getter(name="timeEnded")
    def time_ended(self) -> str:
        """
        End time of the trace.
        """
        return pulumi.get(self, "time_ended")

    @property
    @pulumi.getter(name="timeStarted")
    def time_started(self) -> str:
        """
        Start time of the trace.
        """
        return pulumi.get(self, "time_started")

    @property
    @pulumi.getter(name="traceKey")
    def trace_key(self) -> str:
        return pulumi.get(self, "trace_key")

    @property
    @pulumi.getter(name="traceSnapshotDetails")
    def trace_snapshot_details(self) -> Sequence['outputs.GetTraceSnapshotDataTraceSnapshotDetailResult']:
        """
        Trace snapshots properties.
        """
        return pulumi.get(self, "trace_snapshot_details")


class AwaitableGetTraceSnapshotDataResult(GetTraceSnapshotDataResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetTraceSnapshotDataResult(
            apm_domain_id=self.apm_domain_id,
            id=self.id,
            is_summarized=self.is_summarized,
            key=self.key,
            snapshot_time=self.snapshot_time,
            thread_id=self.thread_id,
            time_ended=self.time_ended,
            time_started=self.time_started,
            trace_key=self.trace_key,
            trace_snapshot_details=self.trace_snapshot_details)


def get_trace_snapshot_data(apm_domain_id: Optional[str] = None,
                            is_summarized: Optional[bool] = None,
                            snapshot_time: Optional[str] = None,
                            thread_id: Optional[str] = None,
                            trace_key: Optional[str] = None,
                            opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetTraceSnapshotDataResult:
    """
    This data source provides details about a specific Trace Snapshot Data resource in Oracle Cloud Infrastructure Apm Traces service.

    Gets the trace snapshots data identified by trace ID.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_trace_snapshot_data = oci.ApmTraces.get_trace_snapshot_data(apm_domain_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        trace_key=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        is_summarized=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        snapshot_time=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        thread_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str apm_domain_id: The APM Domain ID the request is intended for.
    :param bool is_summarized: If enabled, then only span level details will be sent.
    :param str snapshot_time: Epoch time of snapshot.
    :param str thread_id: Thread id for which snapshots needs to be retrieved. This is an identifier of a thread, and is a positive long number generated when when a thread is created.
    :param str trace_key: Unique Application Performance Monitoring trace identifier (traceId).
    """
    __args__ = dict()
    __args__['apmDomainId'] = apm_domain_id
    __args__['isSummarized'] = is_summarized
    __args__['snapshotTime'] = snapshot_time
    __args__['threadId'] = thread_id
    __args__['traceKey'] = trace_key
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:ApmTraces/getTraceSnapshotData:getTraceSnapshotData', __args__, opts=opts, typ=GetTraceSnapshotDataResult).value

    return AwaitableGetTraceSnapshotDataResult(
        apm_domain_id=__ret__.apm_domain_id,
        id=__ret__.id,
        is_summarized=__ret__.is_summarized,
        key=__ret__.key,
        snapshot_time=__ret__.snapshot_time,
        thread_id=__ret__.thread_id,
        time_ended=__ret__.time_ended,
        time_started=__ret__.time_started,
        trace_key=__ret__.trace_key,
        trace_snapshot_details=__ret__.trace_snapshot_details)


@_utilities.lift_output_func(get_trace_snapshot_data)
def get_trace_snapshot_data_output(apm_domain_id: Optional[pulumi.Input[str]] = None,
                                   is_summarized: Optional[pulumi.Input[Optional[bool]]] = None,
                                   snapshot_time: Optional[pulumi.Input[Optional[str]]] = None,
                                   thread_id: Optional[pulumi.Input[Optional[str]]] = None,
                                   trace_key: Optional[pulumi.Input[str]] = None,
                                   opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetTraceSnapshotDataResult]:
    """
    This data source provides details about a specific Trace Snapshot Data resource in Oracle Cloud Infrastructure Apm Traces service.

    Gets the trace snapshots data identified by trace ID.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_trace_snapshot_data = oci.ApmTraces.get_trace_snapshot_data(apm_domain_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        trace_key=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        is_summarized=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        snapshot_time=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        thread_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str apm_domain_id: The APM Domain ID the request is intended for.
    :param bool is_summarized: If enabled, then only span level details will be sent.
    :param str snapshot_time: Epoch time of snapshot.
    :param str thread_id: Thread id for which snapshots needs to be retrieved. This is an identifier of a thread, and is a positive long number generated when when a thread is created.
    :param str trace_key: Unique Application Performance Monitoring trace identifier (traceId).
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['AgentArgs', 'Agent']

@pulumi.input_type
class AgentArgs:
    def __init__(__self__, *,
                 agent_type: pulumi.Input[str],
                 agent_version: pulumi.Input[str],
                 compartment_id: pulumi.Input[str],
                 display_name: pulumi.Input[str],
                 environment_id: pulumi.Input[str],
                 os_version: pulumi.Input[str],
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None):
        """
        The set of arguments for constructing a Agent resource.
        :param pulumi.Input[str] agent_type: Agent identifier.
        :param pulumi.Input[str] agent_version: Agent identifier.
        :param pulumi.Input[str] compartment_id: (Updatable) Compartment identifier.
        :param pulumi.Input[str] display_name: (Updatable) Agent identifier.
        :param pulumi.Input[str] environment_id: Environment identifier.
        :param pulumi.Input[str] os_version: OS version.
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        :param pulumi.Input[Mapping[str, Any]] defined_tags: (Updatable) The defined tags associated with this resource, if any. Each key is predefined and scoped to namespaces. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Operations.CostCenter": "42"}`
        :param pulumi.Input[Mapping[str, Any]] freeform_tags: (Updatable) The freeform tags associated with this resource, if any. Each tag is a simple key-value pair with no predefined name, type, or namespace/scope. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Department": "Finance"}`
        """
        pulumi.set(__self__, "agent_type", agent_type)
        pulumi.set(__self__, "agent_version", agent_version)
        pulumi.set(__self__, "compartment_id", compartment_id)
        pulumi.set(__self__, "display_name", display_name)
        pulumi.set(__self__, "environment_id", environment_id)
        pulumi.set(__self__, "os_version", os_version)
        if defined_tags is not None:
            pulumi.set(__self__, "defined_tags", defined_tags)
        if freeform_tags is not None:
            pulumi.set(__self__, "freeform_tags", freeform_tags)

    @property
    @pulumi.getter(name="agentType")
    def agent_type(self) -> pulumi.Input[str]:
        """
        Agent identifier.
        """
        return pulumi.get(self, "agent_type")

    @agent_type.setter
    def agent_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "agent_type", value)

    @property
    @pulumi.getter(name="agentVersion")
    def agent_version(self) -> pulumi.Input[str]:
        """
        Agent identifier.
        """
        return pulumi.get(self, "agent_version")

    @agent_version.setter
    def agent_version(self, value: pulumi.Input[str]):
        pulumi.set(self, "agent_version", value)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> pulumi.Input[str]:
        """
        (Updatable) Compartment identifier.
        """
        return pulumi.get(self, "compartment_id")

    @compartment_id.setter
    def compartment_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "compartment_id", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Input[str]:
        """
        (Updatable) Agent identifier.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="environmentId")
    def environment_id(self) -> pulumi.Input[str]:
        """
        Environment identifier.
        """
        return pulumi.get(self, "environment_id")

    @environment_id.setter
    def environment_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "environment_id", value)

    @property
    @pulumi.getter(name="osVersion")
    def os_version(self) -> pulumi.Input[str]:
        """
        OS version.


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "os_version")

    @os_version.setter
    def os_version(self, value: pulumi.Input[str]):
        pulumi.set(self, "os_version", value)

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        (Updatable) The defined tags associated with this resource, if any. Each key is predefined and scoped to namespaces. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Operations.CostCenter": "42"}`
        """
        return pulumi.get(self, "defined_tags")

    @defined_tags.setter
    def defined_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "defined_tags", value)

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        (Updatable) The freeform tags associated with this resource, if any. Each tag is a simple key-value pair with no predefined name, type, or namespace/scope. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Department": "Finance"}`
        """
        return pulumi.get(self, "freeform_tags")

    @freeform_tags.setter
    def freeform_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "freeform_tags", value)


@pulumi.input_type
class _AgentState:
    def __init__(__self__, *,
                 agent_pub_key: Optional[pulumi.Input[str]] = None,
                 agent_type: Optional[pulumi.Input[str]] = None,
                 agent_version: Optional[pulumi.Input[str]] = None,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 environment_id: Optional[pulumi.Input[str]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 heart_beat_status: Optional[pulumi.Input[str]] = None,
                 lifecycle_details: Optional[pulumi.Input[str]] = None,
                 os_version: Optional[pulumi.Input[str]] = None,
                 plugin_lists: Optional[pulumi.Input[Sequence[pulumi.Input['AgentPluginListArgs']]]] = None,
                 state: Optional[pulumi.Input[str]] = None,
                 system_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 time_created: Optional[pulumi.Input[str]] = None,
                 time_expire_agent_key_in_ms: Optional[pulumi.Input[str]] = None,
                 time_last_sync_received: Optional[pulumi.Input[str]] = None,
                 time_updated: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Agent resources.
        :param pulumi.Input[str] agent_pub_key: Resource principal public key.
        :param pulumi.Input[str] agent_type: Agent identifier.
        :param pulumi.Input[str] agent_version: Agent identifier.
        :param pulumi.Input[str] compartment_id: (Updatable) Compartment identifier.
        :param pulumi.Input[Mapping[str, Any]] defined_tags: (Updatable) The defined tags associated with this resource, if any. Each key is predefined and scoped to namespaces. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Operations.CostCenter": "42"}`
        :param pulumi.Input[str] display_name: (Updatable) Agent identifier.
        :param pulumi.Input[str] environment_id: Environment identifier.
        :param pulumi.Input[Mapping[str, Any]] freeform_tags: (Updatable) The freeform tags associated with this resource, if any. Each tag is a simple key-value pair with no predefined name, type, or namespace/scope. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Department": "Finance"}`
        :param pulumi.Input[str] heart_beat_status: The current heartbeat status of the Agent based on its timeLastSyncReceived value.
        :param pulumi.Input[str] lifecycle_details: A message describing the current state in more detail. For example, it can be used to provide actionable information for a resource in Failed state.
        :param pulumi.Input[str] os_version: OS version.
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        :param pulumi.Input[Sequence[pulumi.Input['AgentPluginListArgs']]] plugin_lists: List of plugins associated with the agent.
        :param pulumi.Input[str] state: The current state of the Agent.
        :param pulumi.Input[Mapping[str, Any]] system_tags: The system tags associated with this resource, if any. The system tags are set by Oracle cloud infrastructure services. Each key is predefined and scoped to namespaces. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{orcl-cloud: {free-tier-retain: true}}`
        :param pulumi.Input[str] time_created: The time when the Agent was created. An RFC3339 formatted datetime string.
        :param pulumi.Input[str] time_expire_agent_key_in_ms: The time since epoch for when the public key will expire. An RFC3339 formatted datetime string.
        :param pulumi.Input[str] time_last_sync_received: The time when the last heartbeat of the Agent was noted. An RFC3339 formatted datetime string.
        :param pulumi.Input[str] time_updated: The time when the Agent was updated. An RFC3339 formatted datetime string.
        """
        if agent_pub_key is not None:
            pulumi.set(__self__, "agent_pub_key", agent_pub_key)
        if agent_type is not None:
            pulumi.set(__self__, "agent_type", agent_type)
        if agent_version is not None:
            pulumi.set(__self__, "agent_version", agent_version)
        if compartment_id is not None:
            pulumi.set(__self__, "compartment_id", compartment_id)
        if defined_tags is not None:
            pulumi.set(__self__, "defined_tags", defined_tags)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if environment_id is not None:
            pulumi.set(__self__, "environment_id", environment_id)
        if freeform_tags is not None:
            pulumi.set(__self__, "freeform_tags", freeform_tags)
        if heart_beat_status is not None:
            pulumi.set(__self__, "heart_beat_status", heart_beat_status)
        if lifecycle_details is not None:
            pulumi.set(__self__, "lifecycle_details", lifecycle_details)
        if os_version is not None:
            pulumi.set(__self__, "os_version", os_version)
        if plugin_lists is not None:
            pulumi.set(__self__, "plugin_lists", plugin_lists)
        if state is not None:
            pulumi.set(__self__, "state", state)
        if system_tags is not None:
            pulumi.set(__self__, "system_tags", system_tags)
        if time_created is not None:
            pulumi.set(__self__, "time_created", time_created)
        if time_expire_agent_key_in_ms is not None:
            pulumi.set(__self__, "time_expire_agent_key_in_ms", time_expire_agent_key_in_ms)
        if time_last_sync_received is not None:
            pulumi.set(__self__, "time_last_sync_received", time_last_sync_received)
        if time_updated is not None:
            pulumi.set(__self__, "time_updated", time_updated)

    @property
    @pulumi.getter(name="agentPubKey")
    def agent_pub_key(self) -> Optional[pulumi.Input[str]]:
        """
        Resource principal public key.
        """
        return pulumi.get(self, "agent_pub_key")

    @agent_pub_key.setter
    def agent_pub_key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "agent_pub_key", value)

    @property
    @pulumi.getter(name="agentType")
    def agent_type(self) -> Optional[pulumi.Input[str]]:
        """
        Agent identifier.
        """
        return pulumi.get(self, "agent_type")

    @agent_type.setter
    def agent_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "agent_type", value)

    @property
    @pulumi.getter(name="agentVersion")
    def agent_version(self) -> Optional[pulumi.Input[str]]:
        """
        Agent identifier.
        """
        return pulumi.get(self, "agent_version")

    @agent_version.setter
    def agent_version(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "agent_version", value)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Compartment identifier.
        """
        return pulumi.get(self, "compartment_id")

    @compartment_id.setter
    def compartment_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "compartment_id", value)

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        (Updatable) The defined tags associated with this resource, if any. Each key is predefined and scoped to namespaces. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Operations.CostCenter": "42"}`
        """
        return pulumi.get(self, "defined_tags")

    @defined_tags.setter
    def defined_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "defined_tags", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Agent identifier.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="environmentId")
    def environment_id(self) -> Optional[pulumi.Input[str]]:
        """
        Environment identifier.
        """
        return pulumi.get(self, "environment_id")

    @environment_id.setter
    def environment_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "environment_id", value)

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        (Updatable) The freeform tags associated with this resource, if any. Each tag is a simple key-value pair with no predefined name, type, or namespace/scope. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Department": "Finance"}`
        """
        return pulumi.get(self, "freeform_tags")

    @freeform_tags.setter
    def freeform_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "freeform_tags", value)

    @property
    @pulumi.getter(name="heartBeatStatus")
    def heart_beat_status(self) -> Optional[pulumi.Input[str]]:
        """
        The current heartbeat status of the Agent based on its timeLastSyncReceived value.
        """
        return pulumi.get(self, "heart_beat_status")

    @heart_beat_status.setter
    def heart_beat_status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "heart_beat_status", value)

    @property
    @pulumi.getter(name="lifecycleDetails")
    def lifecycle_details(self) -> Optional[pulumi.Input[str]]:
        """
        A message describing the current state in more detail. For example, it can be used to provide actionable information for a resource in Failed state.
        """
        return pulumi.get(self, "lifecycle_details")

    @lifecycle_details.setter
    def lifecycle_details(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "lifecycle_details", value)

    @property
    @pulumi.getter(name="osVersion")
    def os_version(self) -> Optional[pulumi.Input[str]]:
        """
        OS version.


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "os_version")

    @os_version.setter
    def os_version(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "os_version", value)

    @property
    @pulumi.getter(name="pluginLists")
    def plugin_lists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AgentPluginListArgs']]]]:
        """
        List of plugins associated with the agent.
        """
        return pulumi.get(self, "plugin_lists")

    @plugin_lists.setter
    def plugin_lists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AgentPluginListArgs']]]]):
        pulumi.set(self, "plugin_lists", value)

    @property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[str]]:
        """
        The current state of the Agent.
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "state", value)

    @property
    @pulumi.getter(name="systemTags")
    def system_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        The system tags associated with this resource, if any. The system tags are set by Oracle cloud infrastructure services. Each key is predefined and scoped to namespaces. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{orcl-cloud: {free-tier-retain: true}}`
        """
        return pulumi.get(self, "system_tags")

    @system_tags.setter
    def system_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "system_tags", value)

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> Optional[pulumi.Input[str]]:
        """
        The time when the Agent was created. An RFC3339 formatted datetime string.
        """
        return pulumi.get(self, "time_created")

    @time_created.setter
    def time_created(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "time_created", value)

    @property
    @pulumi.getter(name="timeExpireAgentKeyInMs")
    def time_expire_agent_key_in_ms(self) -> Optional[pulumi.Input[str]]:
        """
        The time since epoch for when the public key will expire. An RFC3339 formatted datetime string.
        """
        return pulumi.get(self, "time_expire_agent_key_in_ms")

    @time_expire_agent_key_in_ms.setter
    def time_expire_agent_key_in_ms(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "time_expire_agent_key_in_ms", value)

    @property
    @pulumi.getter(name="timeLastSyncReceived")
    def time_last_sync_received(self) -> Optional[pulumi.Input[str]]:
        """
        The time when the last heartbeat of the Agent was noted. An RFC3339 formatted datetime string.
        """
        return pulumi.get(self, "time_last_sync_received")

    @time_last_sync_received.setter
    def time_last_sync_received(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "time_last_sync_received", value)

    @property
    @pulumi.getter(name="timeUpdated")
    def time_updated(self) -> Optional[pulumi.Input[str]]:
        """
        The time when the Agent was updated. An RFC3339 formatted datetime string.
        """
        return pulumi.get(self, "time_updated")

    @time_updated.setter
    def time_updated(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "time_updated", value)


class Agent(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 agent_type: Optional[pulumi.Input[str]] = None,
                 agent_version: Optional[pulumi.Input[str]] = None,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 environment_id: Optional[pulumi.Input[str]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 os_version: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        This resource provides the Agent resource in Oracle Cloud Infrastructure Cloud Bridge service.

        Creates an Agent.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_oci as oci

        test_agent = oci.cloud_bridge.Agent("testAgent",
            agent_type=var["agent_agent_type"],
            agent_version=var["agent_agent_version"],
            compartment_id=var["compartment_id"],
            display_name=var["agent_display_name"],
            environment_id=oci_cloud_bridge_environment["test_environment"]["id"],
            os_version=var["agent_os_version"],
            defined_tags={
                "Operations.CostCenter": "42",
            },
            freeform_tags={
                "Department": "Finance",
            })
        ```

        ## Import

        Agents can be imported using the `id`, e.g.

        ```sh
         $ pulumi import oci:CloudBridge/agent:Agent test_agent "id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] agent_type: Agent identifier.
        :param pulumi.Input[str] agent_version: Agent identifier.
        :param pulumi.Input[str] compartment_id: (Updatable) Compartment identifier.
        :param pulumi.Input[Mapping[str, Any]] defined_tags: (Updatable) The defined tags associated with this resource, if any. Each key is predefined and scoped to namespaces. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Operations.CostCenter": "42"}`
        :param pulumi.Input[str] display_name: (Updatable) Agent identifier.
        :param pulumi.Input[str] environment_id: Environment identifier.
        :param pulumi.Input[Mapping[str, Any]] freeform_tags: (Updatable) The freeform tags associated with this resource, if any. Each tag is a simple key-value pair with no predefined name, type, or namespace/scope. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Department": "Finance"}`
        :param pulumi.Input[str] os_version: OS version.
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AgentArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource provides the Agent resource in Oracle Cloud Infrastructure Cloud Bridge service.

        Creates an Agent.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_oci as oci

        test_agent = oci.cloud_bridge.Agent("testAgent",
            agent_type=var["agent_agent_type"],
            agent_version=var["agent_agent_version"],
            compartment_id=var["compartment_id"],
            display_name=var["agent_display_name"],
            environment_id=oci_cloud_bridge_environment["test_environment"]["id"],
            os_version=var["agent_os_version"],
            defined_tags={
                "Operations.CostCenter": "42",
            },
            freeform_tags={
                "Department": "Finance",
            })
        ```

        ## Import

        Agents can be imported using the `id`, e.g.

        ```sh
         $ pulumi import oci:CloudBridge/agent:Agent test_agent "id"
        ```

        :param str resource_name: The name of the resource.
        :param AgentArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AgentArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 agent_type: Optional[pulumi.Input[str]] = None,
                 agent_version: Optional[pulumi.Input[str]] = None,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 environment_id: Optional[pulumi.Input[str]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 os_version: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AgentArgs.__new__(AgentArgs)

            if agent_type is None and not opts.urn:
                raise TypeError("Missing required property 'agent_type'")
            __props__.__dict__["agent_type"] = agent_type
            if agent_version is None and not opts.urn:
                raise TypeError("Missing required property 'agent_version'")
            __props__.__dict__["agent_version"] = agent_version
            if compartment_id is None and not opts.urn:
                raise TypeError("Missing required property 'compartment_id'")
            __props__.__dict__["compartment_id"] = compartment_id
            __props__.__dict__["defined_tags"] = defined_tags
            if display_name is None and not opts.urn:
                raise TypeError("Missing required property 'display_name'")
            __props__.__dict__["display_name"] = display_name
            if environment_id is None and not opts.urn:
                raise TypeError("Missing required property 'environment_id'")
            __props__.__dict__["environment_id"] = environment_id
            __props__.__dict__["freeform_tags"] = freeform_tags
            if os_version is None and not opts.urn:
                raise TypeError("Missing required property 'os_version'")
            __props__.__dict__["os_version"] = os_version
            __props__.__dict__["agent_pub_key"] = None
            __props__.__dict__["heart_beat_status"] = None
            __props__.__dict__["lifecycle_details"] = None
            __props__.__dict__["plugin_lists"] = None
            __props__.__dict__["state"] = None
            __props__.__dict__["system_tags"] = None
            __props__.__dict__["time_created"] = None
            __props__.__dict__["time_expire_agent_key_in_ms"] = None
            __props__.__dict__["time_last_sync_received"] = None
            __props__.__dict__["time_updated"] = None
        super(Agent, __self__).__init__(
            'oci:CloudBridge/agent:Agent',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            agent_pub_key: Optional[pulumi.Input[str]] = None,
            agent_type: Optional[pulumi.Input[str]] = None,
            agent_version: Optional[pulumi.Input[str]] = None,
            compartment_id: Optional[pulumi.Input[str]] = None,
            defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
            display_name: Optional[pulumi.Input[str]] = None,
            environment_id: Optional[pulumi.Input[str]] = None,
            freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
            heart_beat_status: Optional[pulumi.Input[str]] = None,
            lifecycle_details: Optional[pulumi.Input[str]] = None,
            os_version: Optional[pulumi.Input[str]] = None,
            plugin_lists: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['AgentPluginListArgs']]]]] = None,
            state: Optional[pulumi.Input[str]] = None,
            system_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
            time_created: Optional[pulumi.Input[str]] = None,
            time_expire_agent_key_in_ms: Optional[pulumi.Input[str]] = None,
            time_last_sync_received: Optional[pulumi.Input[str]] = None,
            time_updated: Optional[pulumi.Input[str]] = None) -> 'Agent':
        """
        Get an existing Agent resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] agent_pub_key: Resource principal public key.
        :param pulumi.Input[str] agent_type: Agent identifier.
        :param pulumi.Input[str] agent_version: Agent identifier.
        :param pulumi.Input[str] compartment_id: (Updatable) Compartment identifier.
        :param pulumi.Input[Mapping[str, Any]] defined_tags: (Updatable) The defined tags associated with this resource, if any. Each key is predefined and scoped to namespaces. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Operations.CostCenter": "42"}`
        :param pulumi.Input[str] display_name: (Updatable) Agent identifier.
        :param pulumi.Input[str] environment_id: Environment identifier.
        :param pulumi.Input[Mapping[str, Any]] freeform_tags: (Updatable) The freeform tags associated with this resource, if any. Each tag is a simple key-value pair with no predefined name, type, or namespace/scope. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Department": "Finance"}`
        :param pulumi.Input[str] heart_beat_status: The current heartbeat status of the Agent based on its timeLastSyncReceived value.
        :param pulumi.Input[str] lifecycle_details: A message describing the current state in more detail. For example, it can be used to provide actionable information for a resource in Failed state.
        :param pulumi.Input[str] os_version: OS version.
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['AgentPluginListArgs']]]] plugin_lists: List of plugins associated with the agent.
        :param pulumi.Input[str] state: The current state of the Agent.
        :param pulumi.Input[Mapping[str, Any]] system_tags: The system tags associated with this resource, if any. The system tags are set by Oracle cloud infrastructure services. Each key is predefined and scoped to namespaces. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{orcl-cloud: {free-tier-retain: true}}`
        :param pulumi.Input[str] time_created: The time when the Agent was created. An RFC3339 formatted datetime string.
        :param pulumi.Input[str] time_expire_agent_key_in_ms: The time since epoch for when the public key will expire. An RFC3339 formatted datetime string.
        :param pulumi.Input[str] time_last_sync_received: The time when the last heartbeat of the Agent was noted. An RFC3339 formatted datetime string.
        :param pulumi.Input[str] time_updated: The time when the Agent was updated. An RFC3339 formatted datetime string.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AgentState.__new__(_AgentState)

        __props__.__dict__["agent_pub_key"] = agent_pub_key
        __props__.__dict__["agent_type"] = agent_type
        __props__.__dict__["agent_version"] = agent_version
        __props__.__dict__["compartment_id"] = compartment_id
        __props__.__dict__["defined_tags"] = defined_tags
        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["environment_id"] = environment_id
        __props__.__dict__["freeform_tags"] = freeform_tags
        __props__.__dict__["heart_beat_status"] = heart_beat_status
        __props__.__dict__["lifecycle_details"] = lifecycle_details
        __props__.__dict__["os_version"] = os_version
        __props__.__dict__["plugin_lists"] = plugin_lists
        __props__.__dict__["state"] = state
        __props__.__dict__["system_tags"] = system_tags
        __props__.__dict__["time_created"] = time_created
        __props__.__dict__["time_expire_agent_key_in_ms"] = time_expire_agent_key_in_ms
        __props__.__dict__["time_last_sync_received"] = time_last_sync_received
        __props__.__dict__["time_updated"] = time_updated
        return Agent(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="agentPubKey")
    def agent_pub_key(self) -> pulumi.Output[str]:
        """
        Resource principal public key.
        """
        return pulumi.get(self, "agent_pub_key")

    @property
    @pulumi.getter(name="agentType")
    def agent_type(self) -> pulumi.Output[str]:
        """
        Agent identifier.
        """
        return pulumi.get(self, "agent_type")

    @property
    @pulumi.getter(name="agentVersion")
    def agent_version(self) -> pulumi.Output[str]:
        """
        Agent identifier.
        """
        return pulumi.get(self, "agent_version")

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> pulumi.Output[str]:
        """
        (Updatable) Compartment identifier.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> pulumi.Output[Mapping[str, Any]]:
        """
        (Updatable) The defined tags associated with this resource, if any. Each key is predefined and scoped to namespaces. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Operations.CostCenter": "42"}`
        """
        return pulumi.get(self, "defined_tags")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[str]:
        """
        (Updatable) Agent identifier.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="environmentId")
    def environment_id(self) -> pulumi.Output[str]:
        """
        Environment identifier.
        """
        return pulumi.get(self, "environment_id")

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> pulumi.Output[Mapping[str, Any]]:
        """
        (Updatable) The freeform tags associated with this resource, if any. Each tag is a simple key-value pair with no predefined name, type, or namespace/scope. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Department": "Finance"}`
        """
        return pulumi.get(self, "freeform_tags")

    @property
    @pulumi.getter(name="heartBeatStatus")
    def heart_beat_status(self) -> pulumi.Output[str]:
        """
        The current heartbeat status of the Agent based on its timeLastSyncReceived value.
        """
        return pulumi.get(self, "heart_beat_status")

    @property
    @pulumi.getter(name="lifecycleDetails")
    def lifecycle_details(self) -> pulumi.Output[str]:
        """
        A message describing the current state in more detail. For example, it can be used to provide actionable information for a resource in Failed state.
        """
        return pulumi.get(self, "lifecycle_details")

    @property
    @pulumi.getter(name="osVersion")
    def os_version(self) -> pulumi.Output[str]:
        """
        OS version.


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "os_version")

    @property
    @pulumi.getter(name="pluginLists")
    def plugin_lists(self) -> pulumi.Output[Sequence['outputs.AgentPluginList']]:
        """
        List of plugins associated with the agent.
        """
        return pulumi.get(self, "plugin_lists")

    @property
    @pulumi.getter
    def state(self) -> pulumi.Output[str]:
        """
        The current state of the Agent.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="systemTags")
    def system_tags(self) -> pulumi.Output[Mapping[str, Any]]:
        """
        The system tags associated with this resource, if any. The system tags are set by Oracle cloud infrastructure services. Each key is predefined and scoped to namespaces. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{orcl-cloud: {free-tier-retain: true}}`
        """
        return pulumi.get(self, "system_tags")

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> pulumi.Output[str]:
        """
        The time when the Agent was created. An RFC3339 formatted datetime string.
        """
        return pulumi.get(self, "time_created")

    @property
    @pulumi.getter(name="timeExpireAgentKeyInMs")
    def time_expire_agent_key_in_ms(self) -> pulumi.Output[str]:
        """
        The time since epoch for when the public key will expire. An RFC3339 formatted datetime string.
        """
        return pulumi.get(self, "time_expire_agent_key_in_ms")

    @property
    @pulumi.getter(name="timeLastSyncReceived")
    def time_last_sync_received(self) -> pulumi.Output[str]:
        """
        The time when the last heartbeat of the Agent was noted. An RFC3339 formatted datetime string.
        """
        return pulumi.get(self, "time_last_sync_received")

    @property
    @pulumi.getter(name="timeUpdated")
    def time_updated(self) -> pulumi.Output[str]:
        """
        The time when the Agent was updated. An RFC3339 formatted datetime string.
        """
        return pulumi.get(self, "time_updated")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetAuditProfilesResult',
    'AwaitableGetAuditProfilesResult',
    'get_audit_profiles',
    'get_audit_profiles_output',
]

@pulumi.output_type
class GetAuditProfilesResult:
    """
    A collection of values returned by getAuditProfiles.
    """
    def __init__(__self__, access_level=None, audit_collected_volume_greater_than_or_equal_to=None, audit_profile_collections=None, audit_profile_id=None, compartment_id=None, compartment_id_in_subtree=None, display_name=None, filters=None, id=None, is_override_global_retention_setting=None, is_paid_usage_enabled=None, state=None, target_id=None):
        if access_level and not isinstance(access_level, str):
            raise TypeError("Expected argument 'access_level' to be a str")
        pulumi.set(__self__, "access_level", access_level)
        if audit_collected_volume_greater_than_or_equal_to and not isinstance(audit_collected_volume_greater_than_or_equal_to, str):
            raise TypeError("Expected argument 'audit_collected_volume_greater_than_or_equal_to' to be a str")
        pulumi.set(__self__, "audit_collected_volume_greater_than_or_equal_to", audit_collected_volume_greater_than_or_equal_to)
        if audit_profile_collections and not isinstance(audit_profile_collections, list):
            raise TypeError("Expected argument 'audit_profile_collections' to be a list")
        pulumi.set(__self__, "audit_profile_collections", audit_profile_collections)
        if audit_profile_id and not isinstance(audit_profile_id, str):
            raise TypeError("Expected argument 'audit_profile_id' to be a str")
        pulumi.set(__self__, "audit_profile_id", audit_profile_id)
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if compartment_id_in_subtree and not isinstance(compartment_id_in_subtree, bool):
            raise TypeError("Expected argument 'compartment_id_in_subtree' to be a bool")
        pulumi.set(__self__, "compartment_id_in_subtree", compartment_id_in_subtree)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if is_override_global_retention_setting and not isinstance(is_override_global_retention_setting, bool):
            raise TypeError("Expected argument 'is_override_global_retention_setting' to be a bool")
        pulumi.set(__self__, "is_override_global_retention_setting", is_override_global_retention_setting)
        if is_paid_usage_enabled and not isinstance(is_paid_usage_enabled, bool):
            raise TypeError("Expected argument 'is_paid_usage_enabled' to be a bool")
        pulumi.set(__self__, "is_paid_usage_enabled", is_paid_usage_enabled)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)
        if target_id and not isinstance(target_id, str):
            raise TypeError("Expected argument 'target_id' to be a str")
        pulumi.set(__self__, "target_id", target_id)

    @property
    @pulumi.getter(name="accessLevel")
    def access_level(self) -> Optional[str]:
        return pulumi.get(self, "access_level")

    @property
    @pulumi.getter(name="auditCollectedVolumeGreaterThanOrEqualTo")
    def audit_collected_volume_greater_than_or_equal_to(self) -> Optional[str]:
        return pulumi.get(self, "audit_collected_volume_greater_than_or_equal_to")

    @property
    @pulumi.getter(name="auditProfileCollections")
    def audit_profile_collections(self) -> Sequence['outputs.GetAuditProfilesAuditProfileCollectionResult']:
        """
        The list of audit_profile_collection.
        """
        return pulumi.get(self, "audit_profile_collections")

    @property
    @pulumi.getter(name="auditProfileId")
    def audit_profile_id(self) -> Optional[str]:
        """
        The OCID of the  parent audit.
        """
        return pulumi.get(self, "audit_profile_id")

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        """
        The OCID of the compartment that contains the audit.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="compartmentIdInSubtree")
    def compartment_id_in_subtree(self) -> Optional[bool]:
        return pulumi.get(self, "compartment_id_in_subtree")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[str]:
        """
        The display name of the audit profile.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetAuditProfilesFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="isOverrideGlobalRetentionSetting")
    def is_override_global_retention_setting(self) -> Optional[bool]:
        """
        Indicates whether audit retention settings like online and offline months is set at the target level overriding the global audit retention settings.
        """
        return pulumi.get(self, "is_override_global_retention_setting")

    @property
    @pulumi.getter(name="isPaidUsageEnabled")
    def is_paid_usage_enabled(self) -> Optional[bool]:
        """
        Indicates if you want to continue collecting audit records beyond the free limit of one million audit records per month per target database, potentially incurring additional charges. The default value is inherited from the global settings.  You can change at the global level or at the target level.
        """
        return pulumi.get(self, "is_paid_usage_enabled")

    @property
    @pulumi.getter
    def state(self) -> Optional[str]:
        """
        The current state of the audit profile.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="targetId")
    def target_id(self) -> Optional[str]:
        """
        The OCID of the Data Safe target for which the audit profile is created.
        """
        return pulumi.get(self, "target_id")


class AwaitableGetAuditProfilesResult(GetAuditProfilesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAuditProfilesResult(
            access_level=self.access_level,
            audit_collected_volume_greater_than_or_equal_to=self.audit_collected_volume_greater_than_or_equal_to,
            audit_profile_collections=self.audit_profile_collections,
            audit_profile_id=self.audit_profile_id,
            compartment_id=self.compartment_id,
            compartment_id_in_subtree=self.compartment_id_in_subtree,
            display_name=self.display_name,
            filters=self.filters,
            id=self.id,
            is_override_global_retention_setting=self.is_override_global_retention_setting,
            is_paid_usage_enabled=self.is_paid_usage_enabled,
            state=self.state,
            target_id=self.target_id)


def get_audit_profiles(access_level: Optional[str] = None,
                       audit_collected_volume_greater_than_or_equal_to: Optional[str] = None,
                       audit_profile_id: Optional[str] = None,
                       compartment_id: Optional[str] = None,
                       compartment_id_in_subtree: Optional[bool] = None,
                       display_name: Optional[str] = None,
                       filters: Optional[Sequence[pulumi.InputType['GetAuditProfilesFilterArgs']]] = None,
                       is_override_global_retention_setting: Optional[bool] = None,
                       is_paid_usage_enabled: Optional[bool] = None,
                       state: Optional[str] = None,
                       target_id: Optional[str] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAuditProfilesResult:
    """
    This data source provides the list of Audit Profiles in Oracle Cloud Infrastructure Data Safe service.

    Gets a list of all audit profiles.

    The ListAuditProfiles operation returns only the audit profiles in the specified `compartmentId`.
    The list does not include any subcompartments of the compartmentId passed.

    The parameter `accessLevel` specifies whether to return only those compartments for which the
    requestor has INSPECT permissions on at least one resource directly
    or indirectly (ACCESSIBLE) (the resource can be in a subcompartment) or to return Not Authorized if
    Principal doesn't have access to even one of the child compartments. This is valid only when
    `compartmentIdInSubtree` is set to `true`.

    The parameter `compartmentIdInSubtree` applies when you perform ListAuditProfiles on the
    `compartmentId` passed and when it is set to true, the entire hierarchy of compartments can be returned.
    To get a full list of all compartments and subcompartments in the tenancy (root compartment),
    set the parameter `compartmentIdInSubtree` to true and `accessLevel` to ACCESSIBLE.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_audit_profiles = oci.DataSafe.get_audit_profiles(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        access_level=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        audit_collected_volume_greater_than_or_equal_to=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        audit_profile_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        compartment_id_in_subtree=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        is_override_global_retention_setting=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        is_paid_usage_enabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        state=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        target_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str access_level: Valid values are RESTRICTED and ACCESSIBLE. Default is RESTRICTED. Setting this to ACCESSIBLE returns only those compartments for which the user has INSPECT permissions directly or indirectly (permissions can be on a resource in a subcompartment). When set to RESTRICTED permissions are checked and no partial results are displayed.
    :param str audit_collected_volume_greater_than_or_equal_to: A filter to return only items that have count of audit records collected greater than or equal to the specified value.
    :param str audit_profile_id: A optional filter to return only resources that match the specified id.
    :param str compartment_id: A filter to return only resources that match the specified compartment OCID.
    :param bool compartment_id_in_subtree: Default is false. When set to true, the hierarchy of compartments is traversed and all compartments and subcompartments in the tenancy are returned. Depends on the 'accessLevel' setting.
    :param str display_name: A filter to return only resources that match the specified display name.
    :param bool is_override_global_retention_setting: A optional filter to return only resources that match the specified retention configured value.
    :param bool is_paid_usage_enabled: Indicates if you want to continue audit record collection beyond the free limit of one million audit records per month per target database, incurring additional charges. The default value is inherited from the global settings. You can change at the global level or at the target level.
    :param str state: A optional filter to return only resources that match the specified lifecycle state.
    :param str target_id: A filter to return only items related to a specific target OCID.
    """
    __args__ = dict()
    __args__['accessLevel'] = access_level
    __args__['auditCollectedVolumeGreaterThanOrEqualTo'] = audit_collected_volume_greater_than_or_equal_to
    __args__['auditProfileId'] = audit_profile_id
    __args__['compartmentId'] = compartment_id
    __args__['compartmentIdInSubtree'] = compartment_id_in_subtree
    __args__['displayName'] = display_name
    __args__['filters'] = filters
    __args__['isOverrideGlobalRetentionSetting'] = is_override_global_retention_setting
    __args__['isPaidUsageEnabled'] = is_paid_usage_enabled
    __args__['state'] = state
    __args__['targetId'] = target_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:DataSafe/getAuditProfiles:getAuditProfiles', __args__, opts=opts, typ=GetAuditProfilesResult).value

    return AwaitableGetAuditProfilesResult(
        access_level=__ret__.access_level,
        audit_collected_volume_greater_than_or_equal_to=__ret__.audit_collected_volume_greater_than_or_equal_to,
        audit_profile_collections=__ret__.audit_profile_collections,
        audit_profile_id=__ret__.audit_profile_id,
        compartment_id=__ret__.compartment_id,
        compartment_id_in_subtree=__ret__.compartment_id_in_subtree,
        display_name=__ret__.display_name,
        filters=__ret__.filters,
        id=__ret__.id,
        is_override_global_retention_setting=__ret__.is_override_global_retention_setting,
        is_paid_usage_enabled=__ret__.is_paid_usage_enabled,
        state=__ret__.state,
        target_id=__ret__.target_id)


@_utilities.lift_output_func(get_audit_profiles)
def get_audit_profiles_output(access_level: Optional[pulumi.Input[Optional[str]]] = None,
                              audit_collected_volume_greater_than_or_equal_to: Optional[pulumi.Input[Optional[str]]] = None,
                              audit_profile_id: Optional[pulumi.Input[Optional[str]]] = None,
                              compartment_id: Optional[pulumi.Input[str]] = None,
                              compartment_id_in_subtree: Optional[pulumi.Input[Optional[bool]]] = None,
                              display_name: Optional[pulumi.Input[Optional[str]]] = None,
                              filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetAuditProfilesFilterArgs']]]]] = None,
                              is_override_global_retention_setting: Optional[pulumi.Input[Optional[bool]]] = None,
                              is_paid_usage_enabled: Optional[pulumi.Input[Optional[bool]]] = None,
                              state: Optional[pulumi.Input[Optional[str]]] = None,
                              target_id: Optional[pulumi.Input[Optional[str]]] = None,
                              opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetAuditProfilesResult]:
    """
    This data source provides the list of Audit Profiles in Oracle Cloud Infrastructure Data Safe service.

    Gets a list of all audit profiles.

    The ListAuditProfiles operation returns only the audit profiles in the specified `compartmentId`.
    The list does not include any subcompartments of the compartmentId passed.

    The parameter `accessLevel` specifies whether to return only those compartments for which the
    requestor has INSPECT permissions on at least one resource directly
    or indirectly (ACCESSIBLE) (the resource can be in a subcompartment) or to return Not Authorized if
    Principal doesn't have access to even one of the child compartments. This is valid only when
    `compartmentIdInSubtree` is set to `true`.

    The parameter `compartmentIdInSubtree` applies when you perform ListAuditProfiles on the
    `compartmentId` passed and when it is set to true, the entire hierarchy of compartments can be returned.
    To get a full list of all compartments and subcompartments in the tenancy (root compartment),
    set the parameter `compartmentIdInSubtree` to true and `accessLevel` to ACCESSIBLE.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_audit_profiles = oci.DataSafe.get_audit_profiles(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        access_level=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        audit_collected_volume_greater_than_or_equal_to=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        audit_profile_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        compartment_id_in_subtree=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        is_override_global_retention_setting=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        is_paid_usage_enabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        state=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        target_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str access_level: Valid values are RESTRICTED and ACCESSIBLE. Default is RESTRICTED. Setting this to ACCESSIBLE returns only those compartments for which the user has INSPECT permissions directly or indirectly (permissions can be on a resource in a subcompartment). When set to RESTRICTED permissions are checked and no partial results are displayed.
    :param str audit_collected_volume_greater_than_or_equal_to: A filter to return only items that have count of audit records collected greater than or equal to the specified value.
    :param str audit_profile_id: A optional filter to return only resources that match the specified id.
    :param str compartment_id: A filter to return only resources that match the specified compartment OCID.
    :param bool compartment_id_in_subtree: Default is false. When set to true, the hierarchy of compartments is traversed and all compartments and subcompartments in the tenancy are returned. Depends on the 'accessLevel' setting.
    :param str display_name: A filter to return only resources that match the specified display name.
    :param bool is_override_global_retention_setting: A optional filter to return only resources that match the specified retention configured value.
    :param bool is_paid_usage_enabled: Indicates if you want to continue audit record collection beyond the free limit of one million audit records per month per target database, incurring additional charges. The default value is inherited from the global settings. You can change at the global level or at the target level.
    :param str state: A optional filter to return only resources that match the specified lifecycle state.
    :param str target_id: A filter to return only items related to a specific target OCID.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetAssetsResult',
    'AwaitableGetAssetsResult',
    'get_assets',
    'get_assets_output',
]

@pulumi.output_type
class GetAssetsResult:
    """
    A collection of values returned by getAssets.
    """
    def __init__(__self__, asset_collections=None, asset_id=None, asset_type=None, compartment_id=None, display_name=None, external_asset_key=None, filters=None, id=None, inventory_id=None, source_key=None, state=None):
        if asset_collections and not isinstance(asset_collections, list):
            raise TypeError("Expected argument 'asset_collections' to be a list")
        pulumi.set(__self__, "asset_collections", asset_collections)
        if asset_id and not isinstance(asset_id, str):
            raise TypeError("Expected argument 'asset_id' to be a str")
        pulumi.set(__self__, "asset_id", asset_id)
        if asset_type and not isinstance(asset_type, str):
            raise TypeError("Expected argument 'asset_type' to be a str")
        pulumi.set(__self__, "asset_type", asset_type)
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if external_asset_key and not isinstance(external_asset_key, str):
            raise TypeError("Expected argument 'external_asset_key' to be a str")
        pulumi.set(__self__, "external_asset_key", external_asset_key)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if inventory_id and not isinstance(inventory_id, str):
            raise TypeError("Expected argument 'inventory_id' to be a str")
        pulumi.set(__self__, "inventory_id", inventory_id)
        if source_key and not isinstance(source_key, str):
            raise TypeError("Expected argument 'source_key' to be a str")
        pulumi.set(__self__, "source_key", source_key)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)

    @property
    @pulumi.getter(name="assetCollections")
    def asset_collections(self) -> Sequence['outputs.GetAssetsAssetCollectionResult']:
        """
        The list of asset_collection.
        """
        return pulumi.get(self, "asset_collections")

    @property
    @pulumi.getter(name="assetId")
    def asset_id(self) -> Optional[str]:
        return pulumi.get(self, "asset_id")

    @property
    @pulumi.getter(name="assetType")
    def asset_type(self) -> Optional[str]:
        """
        The type of asset.
        """
        return pulumi.get(self, "asset_type")

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        """
        The OCID of the compartment to which an asset belongs to.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[str]:
        """
        Asset display name.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="externalAssetKey")
    def external_asset_key(self) -> Optional[str]:
        """
        The key of the asset from the external environment.
        """
        return pulumi.get(self, "external_asset_key")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetAssetsFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="inventoryId")
    def inventory_id(self) -> Optional[str]:
        """
        Inventory ID to which an asset belongs to.
        """
        return pulumi.get(self, "inventory_id")

    @property
    @pulumi.getter(name="sourceKey")
    def source_key(self) -> Optional[str]:
        """
        The source key that the asset belongs to.
        """
        return pulumi.get(self, "source_key")

    @property
    @pulumi.getter
    def state(self) -> Optional[str]:
        """
        The current state of the asset.
        """
        return pulumi.get(self, "state")


class AwaitableGetAssetsResult(GetAssetsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAssetsResult(
            asset_collections=self.asset_collections,
            asset_id=self.asset_id,
            asset_type=self.asset_type,
            compartment_id=self.compartment_id,
            display_name=self.display_name,
            external_asset_key=self.external_asset_key,
            filters=self.filters,
            id=self.id,
            inventory_id=self.inventory_id,
            source_key=self.source_key,
            state=self.state)


def get_assets(asset_id: Optional[str] = None,
               asset_type: Optional[str] = None,
               compartment_id: Optional[str] = None,
               display_name: Optional[str] = None,
               external_asset_key: Optional[str] = None,
               filters: Optional[Sequence[pulumi.InputType['GetAssetsFilterArgs']]] = None,
               inventory_id: Optional[str] = None,
               source_key: Optional[str] = None,
               state: Optional[str] = None,
               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAssetsResult:
    """
    This data source provides the list of Assets in Oracle Cloud Infrastructure Cloud Bridge service.

    Returns a list of assets.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_assets = oci.CloudBridge.get_assets(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        asset_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        asset_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        external_asset_key=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        inventory_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        source_key=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        state=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str asset_id: Unique asset identifier.
    :param str asset_type: The type of asset.
    :param str compartment_id: The ID of the compartment in which to list resources.
    :param str display_name: A filter to return only resources that match the entire display name given.
    :param str external_asset_key: External asset key.
    :param str inventory_id: Unique Inventory identifier.
    :param str source_key: Source key from where the assets originate.
    :param str state: A filter to return only assets whose lifecycleState matches the given lifecycleState.
    """
    __args__ = dict()
    __args__['assetId'] = asset_id
    __args__['assetType'] = asset_type
    __args__['compartmentId'] = compartment_id
    __args__['displayName'] = display_name
    __args__['externalAssetKey'] = external_asset_key
    __args__['filters'] = filters
    __args__['inventoryId'] = inventory_id
    __args__['sourceKey'] = source_key
    __args__['state'] = state
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:CloudBridge/getAssets:getAssets', __args__, opts=opts, typ=GetAssetsResult).value

    return AwaitableGetAssetsResult(
        asset_collections=__ret__.asset_collections,
        asset_id=__ret__.asset_id,
        asset_type=__ret__.asset_type,
        compartment_id=__ret__.compartment_id,
        display_name=__ret__.display_name,
        external_asset_key=__ret__.external_asset_key,
        filters=__ret__.filters,
        id=__ret__.id,
        inventory_id=__ret__.inventory_id,
        source_key=__ret__.source_key,
        state=__ret__.state)


@_utilities.lift_output_func(get_assets)
def get_assets_output(asset_id: Optional[pulumi.Input[Optional[str]]] = None,
                      asset_type: Optional[pulumi.Input[Optional[str]]] = None,
                      compartment_id: Optional[pulumi.Input[str]] = None,
                      display_name: Optional[pulumi.Input[Optional[str]]] = None,
                      external_asset_key: Optional[pulumi.Input[Optional[str]]] = None,
                      filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetAssetsFilterArgs']]]]] = None,
                      inventory_id: Optional[pulumi.Input[Optional[str]]] = None,
                      source_key: Optional[pulumi.Input[Optional[str]]] = None,
                      state: Optional[pulumi.Input[Optional[str]]] = None,
                      opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetAssetsResult]:
    """
    This data source provides the list of Assets in Oracle Cloud Infrastructure Cloud Bridge service.

    Returns a list of assets.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_assets = oci.CloudBridge.get_assets(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        asset_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        asset_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        external_asset_key=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        inventory_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        source_key=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        state=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str asset_id: Unique asset identifier.
    :param str asset_type: The type of asset.
    :param str compartment_id: The ID of the compartment in which to list resources.
    :param str display_name: A filter to return only resources that match the entire display name given.
    :param str external_asset_key: External asset key.
    :param str inventory_id: Unique Inventory identifier.
    :param str source_key: Source key from where the assets originate.
    :param str state: A filter to return only assets whose lifecycleState matches the given lifecycleState.
    """
    ...
